@@ -30,6 +30,7 @@ from pyresample.future.geometry import AreaDefinition, SwathDefinition
 from pyresample.future.geometry.area import ignore_pyproj_proj_warnings
 from pyresample.future.geometry.base import get_array_hashable
 from pyresample.geometry import AreaDefinition as LegacyAreaDefinition
+from pyresample.geometry import DynamicAreaDefinition
 from pyresample.test.utils import assert_future_geometry
 
 
@@ -1062,6 +1063,21 @@ class TestAreaDefinition:
         geo_res = area_def.geocentric_resolution()
         np.testing.assert_allclose(298.647232, geo_res, atol=1e-1)
 
+    def test_area_def_geocentric_resolution_close_dist(self, create_test_area):
+        """Test geocentric resolution when distance range isn't big enough for histogram bins.
+
+        The method currently uses `np.histogram_bin_edges`. Starting in numpy
+        2.1.0, if the number of bins requested (10 in this default case) can't
+        be created because the range of the data is too small, it will raise an
+        exception. This test makes sure that geocentric_resolution doesn't
+        error out when this case is encountered.
+
+        """
+        # this area is known to produce horizontal distances of ~999.9999989758
+        # and trigger the error in numpy 2.1.0
+        ar = create_test_area(4087, 5, 5, (-2500.0, -2500.0, 2500.0, 2500.0))
+        np.testing.assert_allclose(ar.geocentric_resolution(), 999.999999, atol=1e-2)
+
     def test_area_def_geocentric_resolution_latlong(self, create_test_area):
         """Test the AreaDefinition.geocentric_resolution method on a latlong projection."""
         area_extent = (-110.0, 45.0, -95.0, 55.0)
@@ -1739,3 +1755,11 @@ def test_non2d_shape_error(shape):
     """Test that non-2D shapes fail."""
     with pytest.raises(NotImplementedError):
         AreaDefinition("EPSG:4326", shape, (-1000.0, -1000.0, 1000.0, 1000.0))
+
+
+def test_dynamic_area_can_use_bounding_box_attribute():
+    """Test that area freezing can use bounding box info."""
+    area_def = DynamicAreaDefinition("test_area", "", "epsg:3035", resolution=500)
+    swath_def_to_freeze_on = SwathDefinition(None, None, attrs=dict(bounding_box=[[0, 20, 20, 0], [55, 55, 45, 45]]))
+    res_area = area_def.freeze(swath_def_to_freeze_on)
+    assert res_area.area_extent == (3533500, 2484500, 5108500, 3588500)
