@@ -16,8 +16,9 @@
 # You should have received a copy of the GNU Lesser General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
 """Utilities for working with projection parameters."""
-
+import contextlib
 import math
+import warnings
 from collections import OrderedDict
 
 import numpy as np
@@ -64,7 +65,7 @@ def proj4_dict_to_str(proj4_dict, sort=False):
     params = []
     for key, val in items:
         key = str(key) if key.startswith('+') else '+' + str(key)
-        if key in ['+no_defs', '+no_off', '+no_rot']:
+        if key in ['+no_defs', '+no_off', '+no_rot'] or val is None:
             param = key
         else:
             param = '{}={}'.format(key, val)
@@ -144,6 +145,7 @@ class DaskFriendlyTransformer:
         result = da.map_blocks(_transform_dask_chunk, x, y,
                                crs_from.to_wkt(), crs_to.to_wkt(),
                                dtype=x.dtype, chunks=x.chunks + ((2,),),
+                               meta=np.array((), dtype=x.dtype),
                                kwargs=self.kwargs,
                                transform_kwargs=kwargs,
                                new_axis=x.ndim)
@@ -154,3 +156,34 @@ class DaskFriendlyTransformer:
     def _transform_numpy(self, x, y, **kwargs):
         transformer = PROJTransformer.from_crs(self.src_crs, self.dst_crs, **self.kwargs)
         return transformer.transform(x, y, **kwargs)
+
+
+@contextlib.contextmanager
+def ignore_pyproj_proj_warnings():
+    """Wrap operations that we know will produce a PROJ.4 precision warning.
+
+    Only to be used internally to Pyresample when we have no other choice but
+    to use PROJ.4 strings/dicts. For example, serialization to YAML or other
+    human-readable formats or testing the methods that produce the PROJ.4
+    versions of the CRS.
+
+    """
+    with warnings.catch_warnings():
+        warnings.filterwarnings(
+            "ignore",
+            "You will likely lose important projection information",
+            UserWarning,
+        )
+        yield
+
+
+def get_geodetic_crs_with_no_datum_shift(crs: CRS) -> CRS:
+    """Get the geodetic CRS for the provided CRS but with no prime meridian shift."""
+    gcrs = crs.geodetic_crs
+    if gcrs.prime_meridian.longitude == 0:
+        return gcrs
+    with ignore_pyproj_proj_warnings():
+        gcrs_dict = gcrs.to_dict()
+    gcrs_dict.pop("pm", None)
+    gcrs_pm0 = CRS.from_dict(gcrs_dict)
+    return gcrs_pm0
